"use client"

import { useState, useEffect } from "react"
import Link from "next/link"
import { ArrowLeft, AlertTriangle, BookOpen, RotateCcw, Award } from "lucide-react"
import Quiz from "@/components/quiz"
import { loadExamQuestions, ExamQuestion } from "@/utils/examLoader"

export default function ExamPage() {
  const [isStarted, setIsStarted] = useState(false)
  const [examQuestions, setExamQuestions] = useState<ExamQuestion[]>([])
  const [examNumber, setExamNumber] = useState<number>(1)
  const [totalExams, setTotalExams] = useState<number>(22) // Nous avons maintenant 22 examens
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)
  const [loadingProgress, setLoadingProgress] = useState(0)
  // État pour stocker les informations d'erreur supplémentaires
  const [errorDetails, setErrorDetails] = useState<{
    totalExams?: number;
    validExamRange?: number[];
  }>({})

  // Function to fetch the next exam number in sequence
  const fetchNextExamNumber = async () => {
    try {
      // Start progress animation
      setLoadingProgress(10);
      
      // Récupérer le nombre total d'examens disponibles
      const response = await fetch('/api/exam-tracker');
      setLoadingProgress(30);
      
      if (!response.ok) throw new Error('Failed to fetch exam tracker');
      const data = await response.json();
      
      setLoadingProgress(50);
      const totalAvailableExams = data.totalExams || 22;
      setTotalExams(totalAvailableExams);
      
      // Utiliser localStorage pour suivre le dernier examen affiché
      let nextExamNumber = 1;
      
      // Vérifier si nous sommes dans un environnement client (avec localStorage disponible)
      if (typeof window !== 'undefined') {
        const lastExamStr = localStorage.getItem('lastExamNumber');
        const lastExam = lastExamStr ? parseInt(lastExamStr, 10) : 0;
        
        // Incrémenter le numéro d'examen, et revenir à 1 si on dépasse le nombre total
        nextExamNumber = lastExam >= totalAvailableExams ? 1 : lastExam + 1;
        
        // Sauvegarder le nouveau numéro d'examen
        localStorage.setItem('lastExamNumber', nextExamNumber.toString());
        console.log(`Nouvel examen sélectionné: ${nextExamNumber}/${totalAvailableExams}`);
      }
      
      setLoadingProgress(100);
      return nextExamNumber;
    } catch (error) {
      console.error('Error fetching exam number:', error);
      setError('Impossible de récupérer le numéro d\'examen. Utilisation de l\'examen par défaut.');
      return 1; // Default to exam 1 if there's an error
    }
  }

  // Load the exam questions when the component mounts or when isStarted changes
  useEffect(() => {
    if (isStarted) {
      const loadExam = async () => {
        console.log('Début du chargement de l\'examen');
        setLoading(true);
        setError(null);
        setErrorDetails({});
        try {
          // Obtenir le prochain numéro d'examen dans la séquence
          const nextExamNumber = await fetchNextExamNumber();
          console.log(`Chargement de l'examen ${nextExamNumber}`);
          
          // Load the questions for this exam
          const response = await fetch(`/api/exams/${nextExamNumber}`);
          console.log('Réponse API reçue:', response.status);
          const data = await response.json();
          console.log('Données reçues:', data);
          
          // Check if the API returned an error
          if (!response.ok) {
            console.error('Erreur API:', data);
            // Si nous avons des informations sur les examens disponibles, les stocker
            if (data.totalExams && data.validExamRange) {
              setErrorDetails({
                totalExams: data.totalExams,
                validExamRange: data.validExamRange
              });
            }
            throw new Error(data.error || `Erreur lors du chargement de l'examen ${nextExamNumber}`);
          }
          
          const questions = data.questions;
          console.log(`Nombre de questions reçues: ${questions ? questions.length : 0}`);
          
          if (!questions || questions.length === 0) {
            throw new Error(`Aucune question trouvée pour l'examen ${nextExamNumber}`);
          }
          
          setExamQuestions(questions);
          setExamNumber(nextExamNumber);
          
          // Mettre à jour le nombre total d'examens si l'API le fournit
          if (data.totalExams) {
            console.log(`Total des examens disponibles: ${data.totalExams}`);
            setTotalExams(data.totalExams);
          }
        } catch (error) {
          console.error('Error loading exam:', error);
          setError(`Une erreur est survenue lors du chargement de l'examen. ${error instanceof Error ? error.message : ''}`);
          // Fallback to an empty array if there's an error
          setExamQuestions([]);
        } finally {
          console.log('Fin du chargement de l\'examen');
          setLoading(false);
        }
      };

      loadExam();
    }
  }, [isStarted]);

  // Function to restart with a new exam
  const handleRestart = () => {
    setIsStarted(false);
    // Short delay before allowing to start again
    setTimeout(() => {
      setIsStarted(true);
    }, 500);
  };

  if (!isStarted) {
    return (
      <div className="min-h-screen bg-gray-50">
        <div className="bg-red-100 py-12 px-4">
          <div className="container mx-auto">
            <Link href="/" className="flex items-center text-gray-700 mb-4 hover:underline">
              <ArrowLeft className="mr-2 h-4 w-4" />
              Retour à l'accueil
            </Link>
            <h1 className="text-3xl font-bold text-gray-900 mb-2">Examen blanc</h1>
            <p className="text-xl text-gray-800">Testez vos connaissances avec un examen complet.</p>
          </div>
        </div>

        <div className="container mx-auto py-8 px-4">
          <div className="bg-white rounded-lg shadow-md p-8 max-w-2xl mx-auto">
            <div className="flex items-center mb-6">
              <BookOpen className="h-8 w-8 text-red-600 mr-3" />
              <h2 className="text-2xl font-bold">Prêt à passer l'examen ?</h2>
            </div>
            
            <p className="text-gray-700 mb-4">
              Cet examen blanc contient des questions couvrant tous les chapitres du code de la route. 
              Vous aurez 30 secondes pour répondre à chaque question.
            </p>
            
            <div className="bg-blue-50 border-l-4 border-blue-400 p-4 mb-6">
              <div className="flex">
                <Award className="h-6 w-6 text-blue-500 mr-3" />
                <div>
                  <p className="font-medium text-blue-700">Progression automatique</p>
                  <p className="text-blue-600">
                    À chaque fois que vous commencez un nouvel examen, vous verrez automatiquement un ensemble 
                    différent de questions. Nous avons {totalExams} examens différents disponibles.
                  </p>
                </div>
              </div>
            </div>

            <div className="bg-yellow-50 border-l-4 border-yellow-400 p-4 mb-6">
              <div className="flex">
                <AlertTriangle className="h-6 w-6 text-yellow-500 mr-3" />
                <div>
                  <p className="font-medium text-yellow-700">Attention</p>
                  <p className="text-yellow-600">
                    Une fois l'examen commencé, vous ne pourrez pas revenir en arrière. Assurez-vous d'être prêt et de
                    disposer de 20 minutes sans interruption.
                  </p>
                </div>
              </div>
            </div>

            <div className="flex justify-between">
              <Link href="/" className="bg-gray-200 hover:bg-gray-300 text-gray-800 py-2 px-6 rounded">
                Annuler
              </Link>
              <button
                onClick={() => setIsStarted(true)}
                className="bg-red-600 hover:bg-red-700 text-white py-2 px-6 rounded flex items-center"
              >
                Commencer l'examen
                <BookOpen className="ml-2 h-5 w-5" />
              </button>
            </div>
          </div>
        </div>
      </div>
    )
  }

  if (loading) {
    return (
      <div className="min-h-screen bg-gray-50 flex items-center justify-center">
        <div className="text-center w-64">
          <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-red-600 mx-auto mb-4"></div>
          <p className="text-xl text-gray-700 mb-4">Chargement de l'examen...</p>
          <div className="w-full bg-gray-200 rounded-full h-2.5">
            <div 
              className="bg-red-600 h-2.5 rounded-full transition-all duration-300" 
              style={{ width: `${loadingProgress}%` }}
            ></div>
          </div>
        </div>
      </div>
    )
  }

  // Cette section était une redéclaration de errorDetails qui a été déplacée en haut du composant

  if (error) {
    return (
      <div className="min-h-screen bg-gray-50 flex items-center justify-center">
        <div className="text-center max-w-md p-8 bg-white rounded-lg shadow-md">
          <div className="text-red-600 mb-4">
            <AlertTriangle className="h-12 w-12 mx-auto" />
          </div>
          <h2 className="text-2xl font-bold text-gray-900 mb-4">Erreur</h2>
          <p className="text-gray-700 mb-6">{error}</p>
          
          {/* Afficher les examens disponibles si nous avons cette information */}
          {errorDetails.validExamRange && errorDetails.validExamRange.length > 0 && (
            <div className="mb-6">
              <p className="text-gray-700 mb-3">Examens disponibles :</p>
              <div className="flex flex-wrap justify-center gap-2">
                {errorDetails.validExamRange.map((num) => (
                  <button
                    key={num}
                    onClick={() => {
                      setExamNumber(num);
                      handleRestart();
                    }}
                    className="bg-red-100 hover:bg-red-200 text-red-800 py-1 px-3 rounded-full"
                  >
                    Examen {num}
                  </button>
                ))}
              </div>
            </div>
          )}
          
          <div className="flex justify-center space-x-4">
            <Link href="/" className="bg-gray-200 hover:bg-gray-300 text-gray-800 py-2 px-6 rounded">
              Retour à l'accueil
            </Link>
            <button
              onClick={handleRestart}
              className="bg-red-600 hover:bg-red-700 text-white py-2 px-6 rounded flex items-center"
            >
              Réessayer
              <RotateCcw className="ml-2 h-4 w-4" />
            </button>
          </div>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen bg-gray-50">
      <div className="bg-red-100 py-4 px-4">
        <div className="container mx-auto flex justify-between items-center">
          <Link href="/" className="flex items-center text-gray-700 hover:underline">
            <ArrowLeft className="mr-1 h-4 w-4" />
            Quitter l'examen
          </Link>
          <div className="flex items-center">
            <span className="bg-red-600 text-white px-3 py-1 rounded-full text-sm font-medium mr-2">
              Examen {examNumber}/{totalExams}
            </span>
            <button
              onClick={handleRestart}
              className="text-gray-700 hover:text-red-600 flex items-center text-sm"
              title="Passer à l'examen suivant"
            >
              <RotateCcw className="mr-1 h-4 w-4" />
              Changer d'examen
            </button>
          </div>
        </div>
      </div>
      <Quiz title="Examen blanc du code de la route" questions={examQuestions} type="exam" />
    </div>
  )
}
